---
title: Upgrade Guide
---

# Upgrade Guide

<div class="documentation__toc"></div>

## Upgrading to 3.7.0 From 3.6

**Estimated Upgrade Time: 10 - 15 Minutes**

> We attempt to document every possible change. Since some of these changes are in obscure parts of the API only a portion of these changes may actually affect your application.{.notice}

Before continuing please refer to the [release notes](../prologue/release-notes) to see more information on what has been changed.

### Updating Dependencies

Update your `composer.json` file to match the 3.7 branch core addons and dependencies: https://github.com/pyrocms/pyrocms/blob/3.7/composer.json#L24-L84

Of course, don't forget to examine any additional addons and packages consumed by your application and verify you are using the proper version for PyroCMS 3.7 support.

#### Private Storage Adapter

The new [Private Storage Adapter extension](https://github.com/anomalylabs/private_storage_adapter-extension) has replaced the `Local` storage adapter due to general safety and aligning with future features around deployment automation.
  
You will likely want to keep the Local Storage Adapter when upgrading existing installations. Simply add the following to your `composer.json` in the `require` section after mirroring the 3.7 `composer.json`:
 
```bash
"anomaly/local_storage_adapter-extension": "~2.1.0",
```

### Update Configuration

Update your configuration according to the following source files:

- [https://github.com/pyrocms/pyrocms/blob/3.7/config/scout.php](https://github.com/pyrocms/pyrocms/blob/3.7/config/scout.php)
- [https://github.com/pyrocms/pyrocms/blob/3.7/config/logging.php](https://github.com/pyrocms/pyrocms/blob/3.7/config/logging.php)
- [https://github.com/pyrocms/pyrocms/blob/3.7/config/debugbar.php](https://github.com/pyrocms/pyrocms/blob/3.7/config/debugbar.php)
- [https://github.com/pyrocms/pyrocms/blob/3.7/config/httpcache.php](https://github.com/pyrocms/pyrocms/blob/3.7/config/httpcache.php)

### Disable Package Discovery for Laravel

Disable package discovery by appending your `composer.json` file: https://github.com/pyrocms/pyrocms/blob/3.7/composer.json#L127-L131

### Composer Update

Now that the `composer.json` file has been brought up to speed we can let composer update our dependencies:

```bash
composer update
```

### Install Search Module

Install the new Search module to fully replace the old TNT search driver.

```bash
php artisan addon:install search
```

### Run Migrations

Migrate the core as well as all installed addons:

```bash
php artisan migrate --path=vendor/anomaly/streams-platform/migrations/application
php artisan migrate --all-addons
```

### Clean Up

It's a good idea to freshen up the entire system's caching and performance utilities:

```bash
php artisan refresh
```

### Define Automatic Overrides

PyroCMS will no longer look through all addons for overridden views. You must define them in your theme or other addon using the `$overrides` property or by using the `ViewOverrides` collection directly.

[Overriding Views](/documentation/streams-platform/latest/templating/views#overriding-views){.link}
